/* --------------------------- k_varchange  ----------------------------------- */
/*                                                                              */
/* Whenever the inlet receives a different value, or receives a bang, outlet 1  */
/* sends a 1 and outlet 2 sends out the inlet value.                            */
/* */
/* Can be used to trim a stream of values. */
/*                                                                              */
/* This program is free software; you can redistribute it and/or                */
/* modify it under the terms of the GNU General Public License                  */
/* as published by the Free Software Foundation; either version 2               */
/* of the License, or (at your option) any later version.                       */
/*                                                                              */
/* This program is distributed in the hope that it will be useful,              */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of               */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                */
/* GNU General Public License for more details.                                 */
/*                                                                              */
/* You should have received a copy of the GNU General Public License            */
/* along with this program; if not, write to the Free Software                  */
/* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.  */
/*                                                                              */
/* ---------------------------------------------------------------------------- */

#include "m_pd.h"
#include <stdio.h>

static char *version = "k_varchange v0.1, written by Kjetil S. Matheussen, k.s.matheussen@notam02.no";
 
typedef struct k_varchange
{
  t_object x_ob;
  t_inlet  *x_inleft;               /* inlet */

  t_outlet *x_outlet;               /* result */

  t_float  x_value;

} t_k_varchange;

static void k_varchange_bang(t_k_varchange *x)
{
  outlet_float(x->x_outlet, x->x_value);
}

static void k_varchange_float(t_k_varchange *x, t_floatarg f)
{
  if (f == x->x_value ) return;

  x->x_value = f;
  k_varchange_bang(x);
}

static t_class *k_varchange_class;

static void *k_varchange_new(t_symbol *s, t_int argc, t_atom* argv)
{
	int i;


    t_k_varchange *x = (t_k_varchange *)pd_new(k_varchange_class);

    x->x_outlet = outlet_new(&x->x_ob, gensym("float"));

    x->x_value=0.0f;

    if(argc>0) x->x_value=atom_getfloatarg(0,argc,argv);

    return (void *)x;
}

void k_varchange_setup(void)
{
    k_varchange_class = class_new(gensym("k_varchange"), (t_newmethod)k_varchange_new,
    	0, sizeof(t_k_varchange), 0, A_GIMME, 0);

    class_addfloat(k_varchange_class, k_varchange_float);

    //    class_addmethod(k_varchange_class, (t_method)k_varchange_ft1, gensym("ft1"), A_FLOAT, 0);

    class_addbang(k_varchange_class, (t_method)k_varchange_bang);

    class_sethelpsymbol(k_varchange_class, gensym("help-k_varchange.pd"));
}

